//
//  HZActionPerformer.h
//  Home Zone Action Bundles
//
//  Created by Jonas Witt on 18.02.07.
//  Copyright 2007 metaquark.de. All rights reserved.
//

#import <Cocoa/Cocoa.h>

@interface HZActionPerformer : NSObject {
	
	@protected
	IBOutlet NSView *optionsView;

	@private
	NSNib *_nib;
	NSString *_identifier;
	NSString *_bundlePath;
	NSMutableDictionary *_properties;
	
}

/*
 * Override this in your subclass to perform your custom action.
 *
 * Return YES if the action was performed successfully, return NO
 * if it wasn't. In any case, set message to indicate what your action did
 * or why it failed. You may also set icon to be displayed with Growl
 * notifications. Don't call [super execute...] if you implement your own
 * action.
 *
 * The default implementation will look for Applescripts or Shell scripts
 * embedded in the bundle and execute them.
 */
- (BOOL)executeAndReturnStatusMessage:(NSString **)message statusIcon:(NSImage **)icon;

/*
 * Returns an array of property names that will be stored persistently for
 * this action. The default implementation looks for the HZActionProperties
 * key in your action's Info.plist
 */
- (NSArray *)persistentProperties;

/*
 * Returns the default value for a given property key. The default implementation
 * looks for the default value in the HZActionPropertiesDefaultValues dictionary
 * in your action's Info.plist
 */
- (id)defaultValueForProperty:(NSString *)property;

/*
 * Returns the options view which is connected to this object in the NIB file
 * that is specified in the HZOptionsNib Info.plist key. Returns nil if there
 * is no NIB file or if the outlet is not connected.
 */
- (NSView *)optionsView;

/*
 * Returns this action's identifier
 */ 
- (NSString *)identifier;

/*
 * Returns the bundle in which this action is stored
 */
- (NSBundle *)bundle;

/*
 * Returns the description for this action from the HZActionDescription
 * key in your action's Info.plist
 */
- (NSString *)actionDescription;

@end
