//
//  HZOpenFileAction.m
//  Home Zone Action Bundles
//
//  Created by Jonas Witt on 27.02.07.
//  Copyright 2007 __MyCompanyName__. All rights reserved.
//

#import "HZOpenFileAction.h"

#import "NiceFileNameFormatter.h"

@implementation HZOpenFileAction

+ (void)initialize
{
    NiceFileNameFormatter *formatter = [[NiceFileNameFormatter alloc] init];
    [NSValueTransformer setValueTransformer:formatter forName:@"NiceFileNameFormatter"];
    [formatter release];
        
    [self setKeys:[NSArray arrayWithObject:@"path"] triggerChangeNotificationsForDependentKey:@"icon"];
}

- (BOOL)executeAndReturnStatusMessage:(NSString **)message statusIcon:(NSImage **)icon;
{
    BOOL ok = NO;
    NSString *msg = nil;
    
    if (path && [path length] > 0)  {
        BOOL isDir;
        if ([[NSFileManager defaultManager] fileExistsAtPath:path isDirectory:&isDir]) {
            if ([path hasSuffix:@".scpt"]) {
                NSAppleScript *script = [[NSAppleScript alloc] initWithContentsOfURL:[NSURL fileURLWithPath:path] error:nil];
                NSDictionary *dict = nil;
                [script executeAndReturnError:&dict];
                [script release];
                ok = dict == nil;
                if (ok)
                    msg = [NSString stringWithFormat:@"Executed Applescript %@", [path lastPathComponent]];
                else
                    msg = [NSString stringWithFormat:@"Failed to execute Applescript %@", [path lastPathComponent]];
            }
            else if (!isDir && [[NSFileManager defaultManager] isExecutableFileAtPath:path]) {
                NSTask *t = [NSTask launchedTaskWithLaunchPath:path arguments:[NSArray array]];
                [t waitUntilExit];
                
                ok = [t terminationStatus] == 0;
                if (ok)
                    msg = [NSString stringWithFormat:@"Executed %@", [path lastPathComponent]];
                else
                    msg = [NSString stringWithFormat:@"Failed to execute %@", [path lastPathComponent]];
            }
            else if (![[NSWorkspace sharedWorkspace] openFile:path]) {
                ok = NO;
                msg = [NSString stringWithFormat:@"Failed to open file %@", [path lastPathComponent]];
            }
            else {
                ok = YES;
                msg = [NSString stringWithFormat:@"Opened file %@", [path lastPathComponent]];
            }
        }
        else {
            NSURL *url = [NSURL URLWithString:path];
            if (url && ![[NSWorkspace sharedWorkspace] openURL:url]) {
                ok = NO;
                msg = [NSString stringWithFormat:@"Failed to open URL %@", path];
            }
            else if (!url) {
                ok = NO;
                msg = [NSString stringWithFormat:@"No such file or URL: %@", path];
            }
            else {
                ok = YES;
                msg = [NSString stringWithFormat:@"Opened URL %@", path];
            }
        }
    }
    else {
        ok = NO;
        msg = @"No file specified";
    }
	
	if (message)
		*message = msg;
	return ok;
}

- (NSArray *)persistentProperties
{
	return [NSArray arrayWithObject:@"path"];
}

- (id)defaultValueForProperty:(NSString *)property
{
    return nil;
}

- (NSImage *)icon
{
    if (!path || [path length] == 0)
        return nil;
    NSImage *i = nil;
    if ([path hasPrefix:@"/"])
        i = [[NSWorkspace sharedWorkspace] iconForFile:path];
    else        
        i = [[[NSImage alloc] initWithContentsOfFile:[[self bundle] pathForImageResource:@"URL"]] autorelease];
    
    if (i) {
#define ACTION_IMG_SIZE 48
        NSImageRep *bestRep = nil;
        float bestRepSize = 0;
        NSEnumerator *e = [[i representations] objectEnumerator];
        NSImageRep *rep;
        while (rep = [e nextObject]) {
            NSSize s = [rep size];
            if (s.width * s.height > bestRepSize) {
                bestRep = rep;
                bestRepSize = s.width * s.height;
            }
        }
        
        NSImage *i2 = [[NSImage alloc] initWithSize:NSMakeSize(ACTION_IMG_SIZE, ACTION_IMG_SIZE)];
        
        [i2 lockFocus];
        [[NSGraphicsContext currentContext] setImageInterpolation: NSImageInterpolationHigh];
        [bestRep drawInRect:NSMakeRect(0, 0, ACTION_IMG_SIZE, ACTION_IMG_SIZE)];
        [i2 unlockFocus];
        
        i = i2;
    }
    return i;
}

@end
